"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.removeFile = exports.fileUploadWithExt = exports.fileUpload = void 0;
const uuid_1 = require("uuid");
const storage_1 = require("firebase/storage");
/**
 * upload a file to firebase storage
 * @param file File
 * @param path path
 * @returns
 */
const fileUpload = (config, file, path) => __awaiter(void 0, void 0, void 0, function* () {
    const storage = (0, storage_1.getStorage)(config);
    const ext = file.name.split(".")[1];
    const newPath = `${path}/${(0, uuid_1.v4)()}.${ext}`;
    try {
        const result = yield (0, storage_1.uploadBytes)((0, storage_1.ref)(storage, newPath), file);
        return yield (0, storage_1.getDownloadURL)(result.ref);
    }
    catch (error) {
        throw new Error("file not uploaded :" + error.message);
    }
});
exports.fileUpload = fileUpload;
/**
 * upload a file to firebase storage
 * @param file File
 * @param path path
 * @returns
 */
const fileUploadWithExt = (config, file, ext, path) => __awaiter(void 0, void 0, void 0, function* () {
    const storage = (0, storage_1.getStorage)(config);
    const newPath = `${path}/${(0, uuid_1.v4)()}.${ext}`;
    try {
        const result = yield (0, storage_1.uploadBytes)((0, storage_1.ref)(storage, newPath), file);
        return yield (0, storage_1.getDownloadURL)(result.ref);
    }
    catch (error) {
        throw new Error("file not uploaded :" + error.message);
    }
});
exports.fileUploadWithExt = fileUploadWithExt;
/**
 * remove a file from firebase storage
 * @param url path
 */
const removeFile = (config, url) => __awaiter(void 0, void 0, void 0, function* () {
    const storage = (0, storage_1.getStorage)(config);
    const refResult = (0, storage_1.ref)(storage, url);
    yield (0, storage_1.deleteObject)(refResult);
});
exports.removeFile = removeFile;
