import { FirebaseApp } from "firebase/app";
import { DocumentData, Query } from "firebase/firestore";
import BaseModel from "../../models/base.model";
import { IWrite } from "../interfaces/write.interface";
import { IRead } from "../interfaces/read.interface";
import { FilterType } from "../types";
/**
 * Represent the logic of the repository
 */
export default abstract class FireRepository<T extends BaseModel> implements IWrite<T>, IRead<T> {
    /**
     * Represent the db connection
     */
    private db;
    /**
     * Represent the firebase collectionName
     */
    collectionName: string;
    /**
     *
     */
    constructor(configuration: FirebaseApp, collectionName: string);
    getAll(filters?: FilterType<T>): Promise<T[]>;
    getOne(id: string): Promise<T>;
    getDocId(id: string): Promise<string>;
    getCollection(): Query<DocumentData>;
    add(entity: T): Promise<T>;
    update(id: string, entity: T): Promise<T>;
    deleteEntity(id: string): Promise<void>;
    remove(id: string): Promise<void>;
}
