"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const firestore_1 = require("firebase/firestore");
const helpers_1 = require("../../helpers");
const uuid_1 = require("uuid");
/**
 * Represent the logic of the repository
 */
class FireRepository {
    /**
     *
     */
    constructor(configuration, collectionName) {
        this.db = (0, firestore_1.getFirestore)(configuration);
        this.collectionName = collectionName;
    }
    getAll(filters) {
        return __awaiter(this, void 0, void 0, function* () {
            let results = this.getCollection();
            if (filters) {
                results = (0, firestore_1.query)(results, (0, firestore_1.where)(filters.key.toString(), "==", filters.criteria));
            }
            return (0, helpers_1.toEntityArray)(yield (0, firestore_1.getDocs)(results));
        });
    }
    getOne(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const response = yield (0, firestore_1.getDocs)((0, firestore_1.query)(this.getCollection(), (0, firestore_1.where)("id", "==", id)));
            if (response.empty) {
                throw new Error("Document not found");
            }
            const doc = response.docs[0];
            return (0, helpers_1.getFormateadFirebaseData)(doc.data());
        });
    }
    getDocId(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const response = yield (0, firestore_1.getDocs)((0, firestore_1.query)(this.getCollection(), (0, firestore_1.where)("id", "==", id)));
            if (response.empty) {
                throw new Error("Document not found");
            }
            return response.docs[0].id;
        });
    }
    getCollection() {
        return (0, firestore_1.query)((0, firestore_1.collection)(this.db, this.collectionName), (0, firestore_1.orderBy)("createdAt", "desc"), (0, firestore_1.where)("isDeleted", "==", false));
    }
    add(entity) {
        return __awaiter(this, void 0, void 0, function* () {
            if (entity === null) {
                throw new Error("Entity is null");
            }
            yield (0, firestore_1.addDoc)((0, firestore_1.collection)(this.db, this.collectionName), Object.assign(Object.assign({}, entity), { createdAt: new Date() }));
            return entity;
        });
    }
    update(id, entity) {
        return __awaiter(this, void 0, void 0, function* () {
            var docId = yield this.getDocId(id);
            try {
                const docRef = (0, firestore_1.doc)(this.db, this.collectionName, docId);
                const data = Object.assign(Object.assign({}, entity), { updatedAt: new Date() });
                yield (0, firestore_1.updateDoc)(docRef, data);
            }
            catch (error) {
                throw new Error("Document not was updated. error:" + error.message);
            }
            return entity;
        });
    }
    deleteEntity(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const docId = yield this.getDocId(id);
            return yield (0, firestore_1.deleteDoc)((0, firestore_1.doc)(this.db, this.collectionName, docId));
        });
    }
    remove(id) {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.update(id, { isDeleted: true, deleteToken: (0, uuid_1.v4)() });
        });
    }
}
exports.default = FireRepository;
