"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const fire_repository_1 = require("../../repositories/implementations/fire.repository");
describe("FireRepository.getAll unit tests", () => {
    test("get all test with results", () => __awaiter(void 0, void 0, void 0, function* () {
        jest
            .spyOn(fire_repository_1.default.prototype, "getAll")
            .mockImplementation((filters) => {
            return Promise.resolve([
                {
                    id: "1",
                    name: "test",
                },
            ]);
        });
        const results = yield fire_repository_1.default.prototype.getAll();
        expect(results.length > 0).toEqual(true);
    }));
    test("get all test not results", () => __awaiter(void 0, void 0, void 0, function* () {
        jest
            .spyOn(fire_repository_1.default.prototype, "getAll")
            .mockImplementation((filters) => {
            return Promise.resolve([]);
        });
        const results = yield fire_repository_1.default.prototype.getAll();
        expect(results.length > 0).toEqual(false);
    }));
    test("get all test with filters", () => __awaiter(void 0, void 0, void 0, function* () {
        jest
            .spyOn(fire_repository_1.default.prototype, "getAll")
            .mockImplementation((filters) => {
            if (filters && filters.key === "name" && filters.criteria === "test") {
                return Promise.resolve([
                    {
                        id: "1",
                        name: "test",
                    },
                ]);
            }
            return Promise.resolve([]);
        });
        const results = yield fire_repository_1.default.prototype.getAll({
            key: "name",
            criteria: "test",
            isEquals: false,
        });
        expect(results.length > 0).toEqual(true);
    }));
    test("get all test with filters not results", () => __awaiter(void 0, void 0, void 0, function* () {
        jest
            .spyOn(fire_repository_1.default.prototype, "getAll")
            .mockImplementation((filters) => {
            if (filters && filters.key === "name" && filters.criteria === "test") {
                return Promise.resolve([
                    {
                        id: "1",
                        name: "test",
                    },
                ]);
            }
            return Promise.resolve([]);
        });
        const results = yield fire_repository_1.default.prototype.getAll();
        expect(results.length > 0).toEqual(false);
    }));
});
describe("FireRepository.getOne unit tests", () => {
    test("get one with result", () => {
        jest
            .spyOn(fire_repository_1.default.prototype, "getOne")
            .mockImplementation((id) => {
            return Promise.resolve({
                id: "1",
                name: "test",
            });
        });
        const result = fire_repository_1.default.prototype.getOne("1");
        expect(result).not.toBeNull();
    });
    test("get one with result", () => {
        jest
            .spyOn(fire_repository_1.default.prototype, "getOne")
            .mockImplementation((id) => {
            if (id === "1") {
                return Promise.resolve({
                    id: "1",
                    name: "test",
                });
            }
            return Promise.resolve(null);
        });
        const result = fire_repository_1.default.prototype.getOne("1");
        expect(result).not.toBeNull();
    });
    test("get one with not found", () => {
        jest
            .spyOn(fire_repository_1.default.prototype, "getOne")
            .mockImplementation((id) => {
            if (id === "1") {
                return Promise.resolve({
                    id: "1",
                    name: "test",
                });
            }
            throw new Error("not found");
        });
        const result = () => fire_repository_1.default.prototype.getOne("2");
        expect(result).toThrow(Error);
    });
    test("get one verify structure", () => __awaiter(void 0, void 0, void 0, function* () {
        jest
            .spyOn(fire_repository_1.default.prototype, "getOne")
            .mockImplementation((id) => {
            return Promise.resolve({
                id: "1",
                name: "test",
            });
        });
        const result = yield fire_repository_1.default.prototype.getOne("1");
        expect(result.id).toBe("1");
        expect(result.name).toBe("test");
    }));
});
describe("FireRepository.add unit tests", () => {
    test("add with result", () => {
        jest
            .spyOn(fire_repository_1.default.prototype, "add")
            .mockImplementation((data) => {
            return Promise.resolve(data);
        });
        const data = {
            name: "test",
            id: "1",
        };
        const result = fire_repository_1.default.prototype.add(data);
        expect(result).not.toBeNull();
    });
    test("add verify structure", () => __awaiter(void 0, void 0, void 0, function* () {
        jest
            .spyOn(fire_repository_1.default.prototype, "add")
            .mockImplementation((data) => {
            return Promise.resolve(data);
        });
        const data = {
            name: "test",
            id: "1",
        };
        const result = yield fire_repository_1.default.prototype.add(data);
        expect(result.id).toBe("1");
        expect(result.name).toBe("test");
    }));
    test("add with error", () => {
        jest
            .spyOn(fire_repository_1.default.prototype, "add")
            .mockImplementation((data) => {
            throw new Error("error");
        });
        const data = {
            name: "test",
            id: "1",
        };
        const result = () => fire_repository_1.default.prototype.add(data);
        expect(result).toThrow(Error);
    });
});
describe("FireRepository.update unit tests", () => {
    test("update success", () => {
        jest
            .spyOn(fire_repository_1.default.prototype, "update")
            .mockImplementation((id, data) => {
            return Promise.resolve(data);
        });
        const data = {
            name: "test",
            id: "1",
        };
        const result = fire_repository_1.default.prototype.update(data.id, data);
        expect(result).not.toBeNull();
    });
    test("update verify structure", () => __awaiter(void 0, void 0, void 0, function* () {
        jest
            .spyOn(fire_repository_1.default.prototype, "update")
            .mockImplementation((id, data) => {
            return Promise.resolve(data);
        });
        const data = {
            name: "test",
            id: "1",
        };
        const result = yield fire_repository_1.default.prototype.update(data.id, data);
        expect(result.id).toBe("1");
        expect(result.name).toBe("test");
    }));
    test("update with error", () => {
        jest
            .spyOn(fire_repository_1.default.prototype, "update")
            .mockImplementation((id, data) => {
            throw new Error("error");
        });
        const data = {
            name: "test",
            id: "1",
        };
        const result = () => fire_repository_1.default.prototype.update(data.id, data);
        expect(result).toThrow(Error);
    });
});
describe("FireRepository.deleteEntity unit tests", () => {
    test("deleteEntity success", () => {
        jest
            .spyOn(fire_repository_1.default.prototype, "deleteEntity")
            .mockImplementation(() => {
            return Promise.resolve();
        });
        fire_repository_1.default.prototype
            .deleteEntity("1")
            .then(() => {
            expect(true).toBe(true);
        })
            .catch(() => {
            expect(true).toBe(false);
        });
    });
    test("deleteEntity with error", () => {
        jest
            .spyOn(fire_repository_1.default.prototype, "deleteEntity")
            .mockImplementation(() => {
            return Promise.reject();
        });
        fire_repository_1.default.prototype
            .deleteEntity("1")
            .then(() => {
            expect(true).toBe(false);
        })
            .catch(() => {
            expect(true).toBe(true);
        });
    });
});
describe("FireRepository.remove unit tests", () => {
    test("remove success", () => {
        jest.spyOn(fire_repository_1.default.prototype, "remove").mockImplementation(() => {
            return Promise.resolve();
        });
        fire_repository_1.default.prototype
            .remove("1")
            .then(() => {
            expect(true).toBe(true);
        })
            .catch(() => {
            expect(true).toBe(false);
        });
    });
    test("remove with error", () => {
        jest.spyOn(fire_repository_1.default.prototype, "remove").mockImplementation(() => {
            return Promise.reject();
        });
        fire_repository_1.default.prototype
            .remove("1")
            .then(() => {
            expect(true).toBe(false);
        })
            .catch(() => {
            expect(true).toBe(true);
        });
    });
});
describe("FireRepository.getCollection unit tests", () => {
    test("getCollection test with results", () => __awaiter(void 0, void 0, void 0, function* () {
        const docD = {
            name: "test",
            id: "2",
        };
        const docs = Object.assign({}, docD);
        jest
            .spyOn(fire_repository_1.default.prototype, "getCollection")
            .mockImplementation(() => {
            return docs;
        });
        const results = fire_repository_1.default.prototype.getCollection();
        expect(results).not.toBeNull();
    }));
});
